@@ -72,7 +72,7 @@ sub init {
 	#do custom stuff here
 	use WebService::Dropbox;
     use IO::File;
-	use JSON;
+	use JSON::MaybeXS;
 	use URI::Escape qw(uri_escape);
 	use File::Basename qw(dirname basename);
 	use Path::Class;
@@ -195,7 +195,7 @@ sub upload {
 		$upload_file->close();
 
 		if(! $self->{_box}->error) {
-			$res = $self->{_box}->media($self->{_config}->{upload_folder} . "/" . basename($upload_filename));
+			$res = $self->{_box}->shares($self->{_config}->{upload_folder} . "/" . basename($upload_filename), {short_url => 0});
 		}
 
 		if(! $self->{_box}->error){
